OC.L10N.register(
    "files",
    {
    "Added to favorites" : "Đã thêm vào mục ưa thích",
    "Removed from favorites" : "Đã xóa khỏi mục ưa thích",
    "You added {file} to your favorites" : "Bạn đã thêm {file} vào mục ưa thích của bạn",
    "You removed {file} from your favorites" : "Bạn đã xóa {file} khỏi mục ưa thích của mình",
    "Favorites" : "Ưa thích",
    "File changes" : "Những thay đổi của tệp",
    "Created by {user}" : "Được tạo bởi {user}",
    "Changed by {user}" : "Thay đổi bởi {user}",
    "Deleted by {user}" : "Đã xóa bởi {user}",
    "Restored by {user}" : "Được khôi phục bởi {user}",
    "Renamed by {user}" : "Đã đổi tên bởi {user}",
    "Moved by {user}" : "Đã di chuyển bởi {user}",
    "\"remote account\"" : "\"tài khoản từ xa\"",
    "You created {file}" : "Bạn đã tạo {file}",
    "You created an encrypted file in {file}" : "Bạn đã tạo một tệp được mã hóa trong {file}",
    "{user} created {file}" : "{user} đã tạo {file}",
    "{user} created an encrypted file in {file}" : "{user} đã tạo một tệp được mã hóa trong {file}",
    "{file} was created in a public folder" : "{file} đã được tạo trong một thư mục công khai",
    "You changed {file}" : "Bạn đã thay đổi {file}",
    "You changed an encrypted file in {file}" : "Bạn đã thay đổi tệp được mã hóa trong {file}",
    "{user} changed {file}" : "{user} đã thay đổi {file}",
    "{user} changed an encrypted file in {file}" : "{user} đã thay đổi tệp được mã hóa trong {file}",
    "You deleted {file}" : "Bạn đã xóa {file}",
    "You deleted an encrypted file in {file}" : "Bạn đã xóa một tệp được mã hóa trong {file}",
    "{user} deleted {file}" : "{user} đã xóa {file}",
    "{user} deleted an encrypted file in {file}" : "{user} đã xóa một tệp được mã hóa trong {file}",
    "You restored {file}" : "Bạn đã khôi phục {file}",
    "{user} restored {file}" : "{user} đã khôi phục {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Bạn đã đổi tên {oldfile} (ẩn) thành {newfile} (ẩn)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Bạn đã đổi tên {oldfile} (ẩn) thành {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "Bạn đã đổi tên {oldfile} thành {newfile} (ẩn)",
    "You renamed {oldfile} to {newfile}" : "Bạn đã đổi tên {oldfile} thành {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} đã đổi tên {oldfile} (ẩn) thành {newfile} (ẩn)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} đã đổi tên {oldfile} (ẩn) thành {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} đã đổi tên {oldfile} thành {newfile} (ẩn)",
    "{user} renamed {oldfile} to {newfile}" : "{user} đã đổi tên {oldfile} thành {newfile}",
    "You moved {oldfile} to {newfile}" : "Bạn đã di chuyển {oldfile} tới {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} đã di chuyển {oldfile} tới {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Một tệp đã được thêm hoặc bị xóa khỏi <strong>mục ưa thích của bạn</strong>",
    "Files" : "Tệp tin",
    "A file or folder has been <strong>changed</strong>" : "Tệp hoặc thư mục đã được <strong>thay đổi</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "Tệp hoặc thư mục ưa thích đã được <strong>thay đổi</strong>",
    "Failed to authorize" : "Không thể xác minh",
    "Invalid folder path" : "Đường dẫn tới thư mục không hợp lệ",
    "Folder not found" : "Không thể tìm thấy thư mục",
    "No favorites" : "Không có mục ưa thích nào",
    "Accept" : "Đồng ý",
    "Reject" : "Từ chối",
    "Incoming ownership transfer from {user}" : "Có yêu cầu chuyển quyền sở hữu từ {user} ",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Bạn có đồng ý chuyển quyền cho {path}? \n\nLưu ý: Quá trình chuyển quyền sau khi chấp nhận có thể mất tới 1 giờ.",
    "Ownership transfer denied" : "Yêu cầu chuyển quyền sở hữu đã bị từ chối",
    "Your ownership transfer of {path} was denied by {user}." : "Yêu cầu chuyển quyền sở hữu của bạn đối với {path} đã bị từ chối bởi{user}.",
    "Ownership transfer failed" : "Việc chuyển quyền sở hữu đã thất bại",
    "Your ownership transfer of {path} to {user} failed." : "Việc chuyển quyền sở hữu {path} sang {user} đã thất bại.",
    "The ownership transfer of {path} from {user} failed." : "Không thể chuyển quyền sở hữu {path} từ {user}.",
    "Ownership transfer done" : "Việc chuyển quyền sở hữu đã được thực hiện",
    "Your ownership transfer of {path} to {user} has completed." : "Việc chuyển quyền sở hữu {path} sang {user} đã hoàn tất.",
    "The ownership transfer of {path} from {user} has completed." : "Việc chuyển quyền sở hữu {path} từ {user} đã hoàn tất.",
    "in %s" : "trong %s",
    "Transferred from %1$s on %2$s" : "Chuyển từ %1$s tại %2$s",
    "File Management" : "Quản lý tệp tin",
    "Home" : "Trang nhà",
    "Target folder does not exist any more" : "Thư mục đích không còn tồn tại",
    "Reload current directory" : "Tải lại thư mục hiện tại",
    "Go to the \"{dir}\" directory" : "Đi đến thư mục \"{dir}\"",
    "Current directory path" : "Đường dẫn hiện tại",
    "Your have used your space quota and cannot upload files anymore" : "Bạn đã sử dụng hết hạn mức dung lượng và không thể tải tệp lên nữa",
    "Drag and drop files here to upload" : "Kéo thả file vào đây để tải lên",
    "Favorite" : "Ưa thích",
    "Back" : "Trở lại",
    "Toggle selection for file \"{displayName}\"" : "Lựa chọn tập tin \"{displayName}\"",
    "Toggle selection for folder \"{displayName}\"" : "Lựa chọn thư mục \"{displayName}\"",
    "File is loading" : "Đang tải tập tin",
    "Folder is loading" : "Đang tải thư mục",
    "Filename" : "Tên tập tin",
    "Folder name" : "Tên thư mục",
    "This node is unavailable" : "Node này không có sẵn",
    "Another entry with the same name already exists." : "Đã tồn tại mục cùng tên",
    "Invalid filename." : "Tên tập tin không hợp lệ.",
    "Renamed \"{oldName}\" to \"{newName}\"" : "Đã đổi tên \"{oldName}\" thành \"{newName}\"",
    "Rename file" : "Đổi tên tệp tin",
    "Folder" : "Thư mục",
    "Pending" : "Đang chờ",
    "Clear filter" : "Xóa bộ lọc",
    "Modified" : "Đã thay đổi vào:",
    "Search everywhere" : "Tìm ở bất kì đâu",
    "Type" : "Loại",
    "Active filters" : "Bộ lọc đang hoạt động",
    "Remove filter" : "Xoá bộ lọc",
    "Total rows summary" : "Tổng số hàng",
    "Toggle selection for all files and folders" : "Lựa chọn toàn bộ tập tin và thư mục",
    "Name" : "Tên",
    "Size" : "Kích cỡ",
    "Actions" : "Hành động",
    "(selected)" : "(đã chọn)",
    "List of files and folders." : "Danh sách các tập tin và thư mục.",
    "Column headers with buttons are sortable." : "Tiêu đề cột có thể sắp xếp được.",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Danh sách này không được hiển thị đầy đủ để tăng hiệu năng. Các tập tin sẽ được hiển thị khi bạn điều hướng qua danh sách.",
    "File not found" : "Không tìm thấy tập tin",
    "{usedQuotaByte} used" : "{usedQuotaByte} đã được sử dụng",
    "{used} of {quota} used" : "{used} trong {quota} đã được sử dụng",
    "{relative}% used" : "đã sử dụng {relative}%",
    "Could not refresh storage stats" : "Không thể làm mới số liệu bộ nhớ",
    "Your storage is full, files can not be updated or synced anymore!" : "Bộ nhớ của bạn đã đầy, các tập tin không thể cập nhật hoặc đồng bộ hóa nữa!",
    "Storage information" : "Thông tin bộ nhớ",
    "Storage quota" : "Thông tin dung lượng",
    "New folder" : "Thư mục mới",
    "Create new folder" : "Tạo thư mục mới",
    "This name is already in use." : "Tên này đã được sử dụng.",
    "Create" : "Tạo",
    "Refresh" : "Tải mới",
    "Fill template fields" : "Tự động điền các trường thông tin",
    "Submit" : "Gửi",
    "Choose a file or folder to transfer" : "Chọn tệp hoặc thư mục cần chuyển",
    "Transfer" : "Chuyển",
    "Transfer {path} to {userid}" : "Chuyển {path} sang {userid}",
    "Invalid path selected" : "Đường dẫn không hợp lệ",
    "Unknown error" : "Lỗi không xác định",
    "Ownership transfer request sent" : "Yêu cầu chuyển quyền sở hữu đã được gửi",
    "Cannot transfer ownership of a file or folder you do not own" : "Không thể chuyển quyền sở hữu tệp hoặc thư mục mà bạn không sở hữu",
    "Transfer ownership of a file or folder" : "Chuyển quyền sở hữu tệp hoặc thư mục",
    "Choose file or folder to transfer" : "Chọn tệp hoặc thư mục để chuyển",
    "Change" : "Thay đổi",
    "New owner" : "Chủ sở hữu mới",
    "Select file or folder to link to" : "Chọn tập tin hoặc thư mục để liên kết tới",
    "Choose {file}" : "Chọn {file}",
    "Clipboard is not available" : "Bộ nhớ tạm không có sẵn",
    "Files settings" : "Cài đặt tập tin",
    "General" : "Cài đặt chung",
    "All files" : "Tất cả tệp tin",
    "Sort favorites first" : "Sắp xếp mục yêu thích trước",
    "Sort folders before files" : "Sắp xếp thư mục trước tập tin",
    "Appearance" : "Giao diện",
    "Show hidden files" : "Hiển thị các tệp ẩn",
    "Crop image previews" : "Xén ảnh xem trước",
    "Additional settings" : "Cài đặt bổ sung",
    "Copy" : "Sao chép",
    "Keyboard shortcuts" : "Phím tắt",
    "Rename" : "Đổi tên",
    "Delete" : "Xóa",
    "Manage tags" : "Quản lý nhãn",
    "Selection" : "Lựa chọn",
    "Deselect all" : "Bỏ chọn tất cả",
    "Navigation" : "Điều hướng",
    "View" : "Xem",
    "Share" : "Chia sẻ",
    "Shared by link" : "Được chia sẻ với liên kết",
    "Shared" : "Đã chia sẻ",
    "Switch to list view" : "Chuyển sang chế độ xem danh sách",
    "Switch to grid view" : "Chuyển sang chế độ xem dạng lưới",
    "Upload was cancelled by user" : "Tải lên bị hủy bởi người dùng",
    "Not enough free space" : "Không đủ dung lượng trống",
    "Operation is blocked by access control" : "Thao tác bị chặn bởi kiểm soát truy cập",
    "Error during upload: {message}" : "Lỗi khi đang tải lên: {message}",
    "Error during upload, status code {status}" : "Lỗi khi đang tải lên, mã lỗi {status}",
    "Unknown error during upload" : "Lỗi không xác định trong quá trình tải lên",
    "Loading current folder" : "Đang tải thư mục hiện tại",
    "Retry" : "Thử lại",
    "No files in here" : "Không có tệp nào",
    "Upload some content or sync with your devices!" : "Tải lên một số nội dung hoặc đồng bộ với thiết bị của bạn!",
    "Go back" : "Quay lại",
    "Views" : "Lượt xem",
    "You" : "Bạn",
    "Shared multiple times with different people" : "Được chia sẻ nhiều lần với những người khác nhau",
    "Error while loading the file data" : "Lỗi xảy ra trong khi tải dữ liệu tệp",
    "Owner" : "Chủ sở hữu",
    "Remove from favorites" : "Xóa khỏi ưa thích",
    "Add to favorites" : "Thêm vào ưa thích",
    "Tags" : "Nhãn",
    "Your files" : "Tập tin của bạn",
    "Open in files" : "Mở trong Tệp",
    "File cannot be accessed" : "Không thể truy cập tập tin",
    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Không thể tìm thấy tệp hoặc bạn không có quyền xem tệp. Hãy yêu cầu người gửi cấp quyền truy cập.",
    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Giới hạn tên tệp để đảm bảo tệp có thể đáp ứng với toàn bộ người dùng. Mặc định hệ thống sẽ cho phép các tập tin có tên hợp lệ trên hệ POSIX (vd. Linux hoặc macOS).",
    "Files compatibility" : "Khả năng tương thích của tập tin",
    "Enforce Windows compatibility" : "Bắt buộc tên tệp phải tương thích với Windows",
    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Tính năng này sẽ chặn tên tệp không hợp lệ trên hệ thống Windows, như sử dụng tên dành riêng hoặc ký tự đặc biệt. Tuy nhiên, tính năng này sẽ không bắt buộc với chữ in hoa và in thường.",
    "Blank" : "Trống",
    "Unable to create new file from template" : "Không thể tạo tệp mới từ mẫu",
    "Pick a template for {name}" : "Hãy chọn một mẫu cho {name}",
    "Create a new file with the selected template" : "Tạo tệp mới với mẫu đã chọn",
    "Creating file" : "Tạo tệp",
    "Leave this share" : "Rời khỏi mục chia sẻ này",
    "Leave these shares" : "Rời khỏi mục chia sẻ",
    "Disconnect storage" : "Ngắt kết nối bộ nhớ",
    "Disconnect storages" : "Ngắt kết nối các bộ nhớ",
    "Delete permanently" : "Xoá vĩnh viễn",
    "Delete and unshare" : "Xoá và dừng chia sẻ",
    "Delete file" : "Xoá tập tin",
    "Delete files" : "Xoá các tập tin",
    "Delete folder" : "Xoá thư mục",
    "Delete folders" : "Xoá các thư mục",
    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Bặn sắp xoá vĩnh viễn {count} mục"],
    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Bạn sắp xoá {count} mục"],
    "Confirm deletion" : "Xác nhận xoá",
    "Cancel" : "Hủy bỏ",
    "Download" : "Tải về",
    "Destination is not a folder" : "Đích đến không phải là một thư mục",
    "This file/folder is already in that directory" : "Tệp/thư mục này đã có trong thư mục đó",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "Bạn không thể di chuyển một tập tin/thư mục vào chính nó hoặc vào một thư mục con của chính nó",
    "(copy)" : "(sao chép)",
    "(copy %n)" : "(sao chép %n)",
    "A file or folder with that name already exists in this folder" : "Tệp hoặc thư mục có tên đó đã tồn tại trong thư mục này",
    "The files are locked" : "Tập tin bị khoá",
    "The file does not exist anymore" : "Tập tin không tồn tại nữa",
    "Choose destination" : "Lựa chọn điểm đến",
    "Copy to {target}" : "Copy to {target}",
    "Move to {target}" : "Di chuyển đến {target}",
    "Move" : "Dịch chuyển",
    "Move or copy operation failed" : "Thao tác di chuyển hoặc sao chép thất bại",
    "Move or copy" : "Di chuyển hoặc sao chép",
    "Open folder {displayName}" : "Mở thư mục {displayName}",
    "Open in Files" : "Mở trong Tệp",
    "Open locally" : "Mở cục bộ (local)/ ngoại tuyến",
    "Failed to redirect to client" : "Không thể chuyển hướng đến ứng dụng khách",
    "Open file locally" : "Mở tệp cục bộ (local)/ ngoại tuyến",
    "Details" : "Chi tiết",
    "View in folder" : "Xem trong thư mục",
    "Today" : "Hôm nay",
    "Last 7 days" : "7 ngày trước",
    "Last 30 days" : "30 ngày trước",
    "Documents" : "Tài liệu",
    "Spreadsheets" : "Bảng tính",
    "Presentations" : "Bản trình chiếu",
    "Folders" : "Thư mục",
    "Audio" : "Âm thanh",
    "Images" : "Hình ảnh",
    "Videos" : "Phim",
    "Created new folder \"{name}\"" : "Đã tạo thư mục mới \"{name}\"",
    "Unable to initialize the templates directory" : "Không thể khởi tạo thư mục mẫu",
    "Create templates folder" : "Tạo thư mục mẫu",
    "Templates" : "Mẫu",
    "New template folder" : "Thư mục mẫu mới",
    "In folder" : "Trong thư mục",
    "Search in folder: {folder}" : "Tìm trong thư mục: {folder}",
    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Trình duyệt của bạn không hỗ trợ Filesystem API. Thư mục không thể tải lên.",
    "No files to upload" : "Không có tệp để tải lên",
    "Unable to create the directory {directory}" : "Không thể tạo đường dẫn {directory}",
    "Some files could not be uploaded" : "Một số tệp tin không thể tải lên",
    "Files uploaded successfully" : "Tệp tin được tải lên thành công",
    "Some files could not be copied" : "Một số tập tin không thể sao chép",
    "Some files could not be moved" : "Một số tập tin không thể dịch chuyển",
    "Files copied successfully" : "Tệp tin được sao chép thành công",
    "Files moved successfully" : "Tệp tin được di chuyển thành công",
    "Conflicts resolution skipped" : "Đã bỏ qua giải quyết xung đột",
    "Upload cancelled" : "Hủy tải lên",
    "Could not rename \"{oldName}\", it does not exist any more" : "Không thể đổi tên \"{oldName}\", tệp tin không còn tồn tại",
    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Tên \"{newName}\" đã được sử dụng trong thư mục \"{dir}\". Vui lòng chọn một tên khác.",
    "Could not rename \"{oldName}\"" : "Không thể đổi tên \"{oldName}\"",
    "This operation is forbidden" : "Thao tác bị cấm",
    "Storage is temporarily not available" : "Kho lưu trữ tạm thời không khả dụng",
    "_%n file_::_%n files_" : ["%n tập tin"],
    "_%n folder_::_%n folders_" : ["%n thư mục"],
    "Filename must not be empty." : "Tên tập tin không thể trống",
    "\"{char}\" is not allowed inside a filename." : "\"{char}\" không được phép bên trong tên tệp.",
    "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" là tên dành riêng và không được phép cho tên tệp.",
    "\"{extension}\" is not an allowed filetype." : "\"{extension}\" không phải là loại tệp được phép.",
    "Filenames must not end with \"{extension}\"." : "Tên tệp không được phép kết thúc bởi \"{extension}\".",
    "List of favorite files and folders." : "Danh sách tệp và thư mục yêu thích.",
    "No favorites yet" : "Chưa có yêu thích nào",
    "Files and folders you mark as favorite will show up here" : "Các tệp và thư mục mà bạn đánh dấu là yêu thích sẽ hiển thị ở đây",
    "List of your files and folders." : "Danh sách các tập tin và thư mục của bạn.",
    "List of your files and folders that are not shared." : "Danh sách tệp tin và thư mục không được chia sẻ của bạn.",
    "No personal files found" : "Không có tệp cá nhân nào được tìm thấy",
    "Files that are not shared will show up here." : "Các tệp và thư mục bạn đã không chia sẻ sẽ hiện thị ở đây.",
    "Recent" : "Gần đây",
    "List of recently modified files and folders." : "Danh sách các tập tin và thư mục được sửa đổi gần đây.",
    "No recently modified files" : "Không có tập tin được sửa đổi gần đây",
    "Files and folders you recently modified will show up here." : "Các tập tin và thư mục bạn sửa đổi gần đây sẽ hiển thị ở đây.",
    "Search" : "Tìm kiếm",
    "No entries found in this folder" : "Chưa có mục nào trong thư mục",
    "Select all" : "Chọn tất cả",
    "Upload too large" : "Tập tin tải lên quá lớn",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Các tập tin bạn đang tải lên vượt quá kích thước tối đa cho phép trên máy chủ .",
    "Upload (max. %s)" : "Tải lên (tối đa %s)",
    "\"{displayName}\" batch action executed successfully" : "Chỉnh sửa hàng loạt \"{displayName}\" được thực hiện thành công",
    "\"{displayName}\" action failed" : "Hành động \"{displayName}\" đã thực thi thất bại",
    "\"{displayName}\" action executed successfully" : "Hành động \"{displayName}\" đã thực thi thành công",
    "WebDAV URL copied to clipboard" : "Đã sao chép URL WebDAV vào bộ nhớ tạm",
    "Enable the grid view" : "Bật chế độ xem lưới",
    "Enable folder tree" : "Bật cây thư mục",
    "Copy to clipboard" : "Sao chép vào bộ nhớ tạm",
    "Use this address to access your Files via WebDAV" : "Sử dụng địa chỉ này để truy cập Tệp của bạn qua WebDAV",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Nếu bạn đã bật 2FA, bạn phải tạo và sử dụng mật khẩu ứng dụng mới bằng cách nhấp vào đây.",
    "Deletion cancelled" : "Thao tác xóa bị hủy",
    "Edit locally" : "Chỉnh sửa cục bộ/ngoại tuyến",
    "Moving \"{source}\" to \"{destination}\" …" : "Di chuyển \"{source}\" đến \"{destination}\" …",
    "Copying \"{source}\" to \"{destination}\" …" : "Sao chéo \"{source}\" đến \"{destination}\" …",
    "Move cancelled" : "Di chuyển bị dừng",
    "Cancelled move or copy of \"{filename}\"." : "Đã huỷ việc di chuyển hoặc sao chép của \"{filename}\".",
    "Cancelled move or copy operation" : "Đã hủy thao tác di chuyển hoặc sao chép",
    "Open details" : "Mở chi tiết",
    "Photos and images" : "Ảnh",
    "New folder creation cancelled" : "Lỗi tạo thư mục",
    "This directory is unavailable, please check the logs or contact the administrator" : "Thư mục này không sẵn có, hãy kiểm tra log hoặc liên hệ người quản lý",
    "All folders" : "Tất cả tệp tin"
},
"nplurals=1; plural=0;");
